==> src_release_V2.10.tar.gz: dserver/system/xdr/src/pin_xdr.c <==
static char RcsId[] =
"@(#)$Header: pin_xdr.c,v 5.21 2001/11/12 10:01:36 goetz Rel $";

/*+*******************************************************************

 File:          pin_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr structure to read without argin argument the whole
                state of the Pinhole device.

 Author(s):	Jens Meyer

 Original:	June 1993

$Revision: 5.21 $
$Date: 2001/11/12 10:01:36 $

$Author: goetz $

$Log:	pin_xdr.c,v $
 * Revision 5.21  2001/11/12  10:01:36  10:01:36  goetz (Andy Goetz)
 * updated C port for Windows 95/98/NT using Visual C++ 6
 * 
Revision 5.20  2001/01/08 12:17:35  goetz
added patch by B.Pedersen to support querying events

Revision 5.19  2000/10/02 12:08:45  goetz
removed stderr from api_xdr.c

Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:47  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:09  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:35  15:16:35  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:41  13:58:41  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:47  10:08:47  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:36  16:48:36  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:52  goetz
Check

 * Revision 4.28  96/10/21  16:22:31  16:22:31  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:40:14  16:40:14  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:05  10:01:05  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:09  16:23:09  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:45  15:01:45  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:22  13:10:22  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:30  11:07:30  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:40  18:37:40  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:41  13:31:41  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:26  17:40:26  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:39  10:33:39  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:18  16:05:18  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:28:03  10:28:03  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:54  09:56:54  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:19:09  17:19:09  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:27:00  14:27:00  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:30  13:19:30  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:25:01  15:25:01  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:23  17:04:23  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:40  16:59:40  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:34  16:34:34  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:51  15:07:51  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:49  18:15:49  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:49  08:55:49  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:59  18:50:59  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:17  18:22:17  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:52  10:50:52  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:37  18:17:37  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:30  14:36:30  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:15  10:52:15  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:29:06  10:29:06  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:30  16:34:30  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:39:06  09:39:06  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/12/01  15:19:42  15:19:42  meyer (Jens Meyer)
 * Initial revision
 * 

 Copyright (c) 1990 by European Synchrotron Radiation Facility,
		       Grenoble, France

*******************************************************************-*/


#include <dev_xdr.h>
#include <pin_xdr.h>



bool_t
xdr_pin_head(xdrs, objp)
	XDR *xdrs;
	pin_head *objp;
{
	if (!xdr_long(xdrs, &objp->main_st)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->dev_diag)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->tuned)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->mode)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_pin_head(objp)
	pin_head *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong (&objp->main_st);
        length = length + xdr_length_DevLong (&objp->dev_diag);
        length = length + xdr_length_DevLong (&objp->tuned);
        length = length + xdr_length_DevLong (&objp->mode);

        return (length);
}




bool_t
xdr_axis_state(xdrs, objp)
	XDR *xdrs;
	axis_state *objp;
{
	if (!xdr_long(xdrs, &objp->unit)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->moving)) {
		return (FALSE);
	}
	if (!xdr_float(xdrs, &objp->mot_pos)) {
		return (FALSE);
	}
	if (!xdr_float(xdrs, &objp->enc_pos)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->switch_st)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->tuned)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_axis_state(objp)
	axis_state *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong (&objp->unit);
        length = length + xdr_length_DevLong (&objp->moving);
        length = length + xdr_length_DevFloat (&objp->mot_pos);
        length = length + xdr_length_DevFloat (&objp->enc_pos);
        length = length + xdr_length_DevLong (&objp->switch_st);
        length = length + xdr_length_DevLong (&objp->tuned);

        return (length);
}




bool_t
xdr_DevPinState(xdrs, objp)
	XDR *xdrs;
	DevPinState *objp;
{
	if (!xdr_pin_head(xdrs, &objp->pin_head)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->z1_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->z2_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->tx_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->tt_state)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_DevPinState(objp)
	DevPinState *objp;
{
        long  length = 0;

        length = length + xdr_length_pin_head (&objp->pin_head);
        length = length + xdr_length_axis_state (&objp->z1_state);
        length = length + xdr_length_axis_state (&objp->z2_state);
        length = length + xdr_length_axis_state (&objp->tx_state);
        length = length + xdr_length_axis_state (&objp->tt_state);

        return (length);
}

==> src_release_V2.12.tar.gz: dserver/system/xdr/src/pin_xdr.c <==
static char RcsId[] =
"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/pin_xdr.c,v 5.22 2002/03/11 12:35:57 goetz Rel $";

/*+*******************************************************************

 File:          pin_xdr.c

 Project:       Device Servers with sun-rpc

 Description:   xdr structure to read without argin argument the whole
                state of the Pinhole device.

 Author(s):	Jens Meyer

 Original:	June 1993

$Revision: 5.22 $
$Date: 2002/03/11 12:35:57 $

$Author: goetz $

$Log: pin_xdr.c,v $
Revision 5.22  2002/03/11 12:35:57  goetz
added extern C prototype to VGC xdr routines for C++

Revision 5.21  2001/11/12 10:01:36  goetz
updated C port for Windows 95/98/NT using Visual C++ 6

Revision 5.20  2001/01/08 12:17:35  goetz
added patch by B.Pedersen to support querying events

Revision 5.19  2000/10/02 12:08:45  goetz
removed stderr from api_xdr.c

Revision 5.18  1999/07/08 14:10:46  goetz
changed _LPfd_set type for Linux in macros.h

Revision 5.17  1998/05/25 17:59:47  klotz
fixed C++ prototypes in api_xdr.h

Revision 5.16  1998/04/29 10:24:09  goetz
macros.h - added __STDCPP__ for HP C++ compiler (aCC)

 * Revision 5.15  97/12/01  15:16:35  15:16:35  klotz (W.D. Klotz)
 * WIN_NT_95_released_NOV_97
 * 
 * Revision 4.34  97/01/30  13:58:41  13:58:41  goetz (Andy Goetz)
 * removed dev_printdebug() from DevXdrKernel.h
 * 
 * Revision 4.33  97/01/09  10:08:47  10:08:47  goetz (Andy Goetz)
 * (xdrproc_t) castings added to maxe_xdr, ram_xdr, thc_xdr, seism_xdr
 * 
 * Revision 4.32  97/01/08  16:48:36  16:48:36  goetz (Andy Goetz)
 * Ported to Linux (2.0.9)
 * 
Revision 4.31  1996/11/18 17:28:52  goetz
Check

 * Revision 4.28  96/10/21  16:22:31  16:22:31  taurel (E.Taurel)
 * Check_in_after_port_to_OS9/ISP_2.1_and_OS9/RPC1.4
 * 
 * Revision 4.27  96/09/17  16:40:14  16:40:14  klotz (W.D. Klotz)
 * WD Klotz: tested NT build  
 * 
 * Revision 4.26  96/07/19  10:01:05  10:01:05  taurel (E.Taurel)
 * Some_change_in_macros.h_for_the_API_port_to_OS-9_Ultra_C++
 * 
 * Revision 4.25  96/06/07  16:23:09  16:23:09  meyer (J.Meyer)
 * Corrected_elif_to_else_in_macros.h
 * 
 * Revision 4.24  96/06/05  15:01:45  15:01:45  meyer (J.Meyer)
 * Corrected_macros.h
 * 
 * Revision 4.23  96/06/03  13:10:22  13:10:22  meyer (J.Meyer)
 * Cleaned-up_MSDOS_and_added_porting_options_for_Windows_NT.
 * 
 * Revision 4.22  96/05/23  11:07:30  11:07:30  taurel (E.Taurel)
 * Added_some_definitions_for_C++_in_API_xdr.h_file
 * 
 * Revision 4.21  96/05/06  18:37:40  18:37:40  meyer (J.Meyer)
 * Fortran_compatibility_for:_dev_xdr.h,macros.h,maxe_xdr.h
 * 
 * Revision 4.20  96/02/27  13:31:41  13:31:41  meyer (J.Meyer)
 * Deleted_Cross_References_To_DSAPI_Library
 * 
 * Revision 4.19  96/01/11  17:40:26  17:40:26  meyer (Jens Meyer)
 * Added_#define_PORTMAP_to_macros.h.
 * 
 * Revision 4.18  95/12/21  10:33:39  10:33:39  meyer (Jens Meyer)
 * Corrected length calculation for D_VAR_MSTATARR.
 * 
 * Revision 4.17  95/08/02  16:05:18  16:05:18  meyer (Jens Meyer)
 * Corrected DevXdrKernel.h after C++ implementation.
 * 
 * Revision 4.15  95/03/02  10:28:03  10:28:03  meyer (Jens Meyer)
 * Added D_VAR_SFRPARR type to the kernel.
 * 
 * Revision 4.14  95/02/20  09:56:54  09:56:54  meyer (Jens Meyer)
 * Passed the compilers for HPUX, SUNOS and UCC after the first windows check in.
 * 
 * Revision 4.13  95/02/10  17:19:09  17:19:09  meyer (Jens Meyer)
 * Deleted
 * 
 * Revision 4.12  95/02/01  14:27:00  14:27:00  klotz (W.D. Klotz)
 * WDK: first successfull compile of dbase, api, xdr on WIN16/3.1
 * 
 * Revision 4.11  95/01/03  13:19:30  13:19:30  meyer (Jens Meyer)
 * Repared bug in dev_cmd_query() for version 3!
 * 
 * Revision 4.10  94/12/08  15:25:01  15:25:01  meyer (Jens Meyer)
 * Changed _manager_data in API_xdr and added old version to API_xdr_vers3.
 * 
 * Revision 4.9  94/11/28  17:04:23  17:04:23  meyer (Jens Meyer)
 * Data types for compatibility with library version 3.x
 * 
 * Revision 4.8  94/08/16  16:59:40  16:59:40  meyer (Jens Meyer)
 * Corrected error in ws_xdr.h
 * 
 * Revision 4.7  94/08/16  16:34:34  16:34:34  meyer (Jens Meyer)
 * Added define for MAX_RESOURCE_FIELD_LENGTH to macros.h
 * 
 * Revision 4.6  94/08/12  15:07:51  15:07:51  meyer (Jens Meyer)
 * Added valriable arguments to all API RPC structures.
 * 
 * Revision 4.5  94/07/20  18:15:49  18:15:49  meyer (Jens Meyer)
 * Changed include files in macros.h!
 * 
 * Revision 4.4  94/07/20  08:55:49  08:55:49  meyer (Jens Meyer)
 * All XDR functions with prototypes!
 * 
 * Revision 4.3  94/07/18  18:50:59  18:50:59  meyer (Jens Meyer)
 * Had to change macros.h, because #define must be in the first column!
 * 
 * Revision 4.2  94/07/18  18:22:17  18:22:17  meyer (Jens Meyer)
 * First test with PC macros for the XDR kernel.
 * 
 * Revision 4.1  94/05/02  10:50:52  10:50:52  meyer (Jens Meyer)
 * For Security System without connection count.
 * 
 * Revision 4.0  94/03/14  18:17:37  18:17:37  meyer (Jens Meyer)
 * Library version with Security System.
 * 
 * Revision 3.50  94/03/12  14:36:30  14:36:30  meyer (Jens Meyer)
 * Changed API xdr structures for security.
 * 
 * Revision 3.35  94/03/03  10:52:15  10:52:15  taurel (Emmanuel TAUREL)
 * Added unsigned long array type in the XDRkernel
 * 
 * Revision 3.34  94/03/03  10:29:06  10:29:06  taurel (Emmanuel TAUREL)
 * Added the unsigned long array type in
 * XDR kernel (LC and ET).
 * 
 * Revision 3.33  94/01/12  16:34:30  16:34:30  meyer (Jens Meyer)
 * Global XDR type array for data collector access
 * 
 * Revision 3.31  93/12/02  09:39:06  09:39:06  meyer (Jens Meyer)
 * New release with small XDR data type kernel.
 * 
 * Revision 1.1  93/12/01  15:19:42  15:19:42  meyer (Jens Meyer)
 * Initial revision
 * 

 Copyright (c) 1990 by European Synchrotron Radiation Facility,
		       Grenoble, France

*******************************************************************-*/


#include <dev_xdr.h>
#include <pin_xdr.h>



bool_t
xdr_pin_head(xdrs, objp)
	XDR *xdrs;
	pin_head *objp;
{
	if (!xdr_long(xdrs, &objp->main_st)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->dev_diag)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->tuned)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->mode)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_pin_head(objp)
	pin_head *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong (&objp->main_st);
        length = length + xdr_length_DevLong (&objp->dev_diag);
        length = length + xdr_length_DevLong (&objp->tuned);
        length = length + xdr_length_DevLong (&objp->mode);

        return (length);
}




bool_t
xdr_axis_state(xdrs, objp)
	XDR *xdrs;
	axis_state *objp;
{
	if (!xdr_long(xdrs, &objp->unit)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->moving)) {
		return (FALSE);
	}
	if (!xdr_float(xdrs, &objp->mot_pos)) {
		return (FALSE);
	}
	if (!xdr_float(xdrs, &objp->enc_pos)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->switch_st)) {
		return (FALSE);
	}
	if (!xdr_long(xdrs, &objp->tuned)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_axis_state(objp)
	axis_state *objp;
{
        long  length = 0;

        length = length + xdr_length_DevLong (&objp->unit);
        length = length + xdr_length_DevLong (&objp->moving);
        length = length + xdr_length_DevFloat (&objp->mot_pos);
        length = length + xdr_length_DevFloat (&objp->enc_pos);
        length = length + xdr_length_DevLong (&objp->switch_st);
        length = length + xdr_length_DevLong (&objp->tuned);

        return (length);
}




bool_t
xdr_DevPinState(xdrs, objp)
	XDR *xdrs;
	DevPinState *objp;
{
	if (!xdr_pin_head(xdrs, &objp->pin_head)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->z1_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->z2_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->tx_state)) {
		return (FALSE);
	}
	if (!xdr_axis_state(xdrs, &objp->tt_state)) {
		return (FALSE);
	}
	return (TRUE);
}

long 
xdr_length_DevPinState(objp)
	DevPinState *objp;
{
        long  length = 0;

        length = length + xdr_length_pin_head (&objp->pin_head);
        length = length + xdr_length_axis_state (&objp->z1_state);
        length = length + xdr_length_axis_state (&objp->z2_state);
        length = length + xdr_length_axis_state (&objp->tx_state);
        length = length + xdr_length_axis_state (&objp->tt_state);

        return (length);
}
